@@ -9,13 +9,13 @@ class c(object):
 # c++类
 class cpp(object):
     # cout类
-    class _Cout(object):
+    class __Cout(object):
         # << 方法
-        def __lshift__(self, other: str) -> "cpp._Cout":
+        def __lshift__(self, other: str) -> "cpp.__Cout":
             print(other, end='')
             return self
 
-    cout = _Cout()
+    cout = __Cout()
     endl = '\n'
 
 
