@@ -8,15 +8,19 @@ def __start() -> None:
 | '--'F|| '--'X|| '--'X|| '--'K|| '--'P|| '--'Y|
 `------'`------'`------'`------'`------'`------'\
 '''
-    from random import randint as rint
-    from sys import version_info as info
+    from random import randint
+    from sys import version_info
+
     from colorama import Fore, Style
+
     from .version import ver
-    color = '' if rint(0, 1) else Fore.GREEN if not rint(0, 4) else Fore.YELLOW if rint(0, 1) else Fore.BLUE
-    print(f"{color}fxxkpy {ver} (Python {'.'.join(map(str, info[0:3]))})")
+
+    color = '' if not randint(0, 2) else Fore.GREEN if not randint(0, 4) else Fore.YELLOW if randint(0, 1) else Fore.BLUE
+    print(f"{color}FxxkPy {ver} (Python {'.'.join(map(str, version_info[0:3]))})")
     print(FxxkPy, end='')
     print(Style.RESET_ALL)
-    del rint, info, Fore, Style, ver, color
+
+    del randint, version_info, Fore, Style, ver, color
 
 
 __start()
